microphone
==========

python audio recorder using pyaudio for audio capture and transmission using zeromq

NOTE: Program is very much in an alpha stage! You've been warned!

Installation
------------

::

    pip install microphone

-or- ::

    pip install git+https://github.com/benhoff/microphone.git

if running from source need to run the command ::

   python setup.py develop
